import static org.junit.jupiter.api.Assertions.*;

import org.junit.jupiter.api.Test;

class ProgramTestFixed {

	@Test
	void testConvertBinaryToInt() {

		String[] input = {"010","110","111","1010101"};
				
		int[] result = Program.ConvertBinaryToInt(input);

		assertEquals(result[0],2);
		assertEquals(result[1],6);
		assertEquals(result[2],7);
		assertEquals(result[3],85);
		
	}

	
	@Test
	void testConvertBase3ToInt() {

		String[] input = {"2","12","10","111"};
				
		int[] result = Program.ConvertBase3ToInt(input);

		assertEquals(result[0],2);
		assertEquals(result[1],5);
		assertEquals(result[2],3);
		assertEquals(result[3],13);
		
	}

	
	@Test
	void testConvertHexToInt() {

		String[] input = {"50","110","FA","B0","F"};
		
		int[] result = Program.ConvertHexToInt(input);

		assertEquals(result[0],80);
		assertEquals(result[1],272);
		assertEquals(result[2],250);
		assertEquals(result[3],176);
		assertEquals(result[4],15);


	}

	@Test
	void testConvertBase20ToInt() {

		//1s, 20s, 400s
		
		String[] input = {"50","110","FA","GH"};
		
		int[] result = Program.ConvertBase20ToInt(input);

		assertEquals(result[0],100);
		assertEquals(result[1],420);
		assertEquals(result[2],310);
		assertEquals(result[3],(16*20)+17);



	}

	
	@Test
	void testUnion() {

	int[] setA = {3,6,8,4,2,1};
	int[] setB = {3,6,7,9,8,7,6,5,15};
	
	int[] setC = {1,2,3,4,5,6,7,8,9,15};
	
	int[] unionSet = Program.Union(setA, setB);
	
	assertEquals(setC.length,unionSet.length);
	
	for(int i: setC) {
		
		Boolean flag = false;
		
		for(int j : unionSet) {
			
			if(i==j) {flag = true;}
			
		}
		
		assertTrue(flag);
		
	}
	
	}

	@Test
	void testIntersection() {

	int[] setA = {3,6,8,4,2,1};
	int[] setB = {3,6,7,9,8,7,6,5,15};
	
	int[] setC = {3,6,8};
	
	int[] interSet = Program.Intersection(setA, setB);
	
	assertEquals(setC.length,interSet.length);
	
	for(int i: setC) {
		
		Boolean flag = false;
		
		for(int j : interSet) {
			
			if(i==j) {flag = true;}
			
		}
		
		assertTrue(flag);
		
	}
	
	}

	
	@Test
	void testDifference() {

	int[] setA = {3,6,8,4,2,1};
	int[] setB = {3,6,7,9,8,7,6,5,15};
	
	int[] setC = {4,2,1};
	
	int[] diffSet = Program.Difference(setA, setB);
	
	assertEquals(setC.length,diffSet.length);
	
	for(int i: setC) {
		
		Boolean flag = false;
		
		for(int j : diffSet) {
			
			if(i==j) {flag = true;}
			
		}
		
		assertTrue(flag);
		
	}
	
	}
	
	@Test
	void testSum() {

		int[] set = {3,6,7,9,8,7,6,5,15};
		
		assertEquals(Program.Sum(set),3+6+7+9+8+7+6+5+15);

	}

	@Test
	void testMean() {

		int[] set = {3,6,7,9,8,7,6,5,15};
		
		assertEquals(Program.Mean(set),((3d+6d+7d+9d+8d+7d+6d+5d+15d)/9d),0.01);


	}

	@Test
	void testMode() {
	
		int[] set = {3,6,7,9,8,7,7,6,5,15};
		
		assertEquals(Program.Mode(set),7);					
	
	}

	@Test
	void testMedian() {

		int[] set = {3,6,7,9,8,6,7,6,5,15};
		
		assertEquals(Program.Median(set),6.5d,0.001);		
	
	}

	@Test
	void testStandardDeviation() {
	int[] set = {3,6,7,9,8,6,7,6,5,15};
		
		assertEquals(Program.StandardDeviation(set),3.19d,0.1);		
	
	}
	
	@Test
	void testRange() {
	
		int[] set = {15,3,7,9,8,7,7,6,5,2};
		
		assertEquals(Program.Range(set),13);					
	
	}
	
	@Test
	void testHarmonicMean() {
	int[] set = {3,6,77};
	
	
		assertEquals(Program.HarmonicMean(set),(3d/((1d/3d)+(1d/6d)+(1d/77d))),0.1);		
	
	}
	

	@Test
	void testComplexSumFunctionA() {
	int[] set = {3,6,77};
		
		assertEquals(Program.ComplexSumFunctionA(set),
				

				(1d+
				Math.pow(6d/2d, 0.5d)+
				(77d/2d))
				/6
				
				
				,0.1);		
	
	}
	
	@Test
	void testMatrixScalar() {
	int[][] matrix = {{1,2},
					  {3,4}};

	int[][] mScaled = Program.MatrixScalarMultiplication(matrix,11);
	
	assertEquals(mScaled[0][0],11);
	assertEquals(mScaled[0][1],22);
	assertEquals(mScaled[1][0],33);
	assertEquals(mScaled[1][1],44);

	
	}
	
/*
	@Test
	void testComplexMatrixOperation() {

		int[][] matrix = {{1,2},
				  {3,4}};

int[][] matrix2 = Program.ComplexMatrixOperation(matrix,matrix,11);

assertEquals(matrix2[0][0],22);
assertEquals(matrix2[0][1],44);
assertEquals(matrix2[1][0],66);
assertEquals(matrix2[1][1],88);



	
	}
*/
	
	@Test
	void testGenerateDistributionForSpecificDie() {

		double[] d = Program.GenerateRandomDistributionForSpecificDie(100000);
		
		
		assertEquals(d[2479],0.0012,0.0001);
	}			
	
	
	@Test
	void testGenerateRandomDistribution() {

		assertEquals(Program.GenerateRandomDistribution(50,5,100000)[89],0.0062,0.0001);
	}

	@Test
	void testGetProbabilityOfResultOrHigher() {

		double d = Program.GetProbabilityOfResultOrHigher(50,10,300);

		assertEquals(d,0.16947000000000007,0.0001);

		
	}

	
	

}
